==> jc-1.4.0.tar.gz: javax/swing/Timer__24Waker.h <==
// class javax.swing.Timer$Waker

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a3a7cdc3e4c7ce28 java_lang_Thread
// @dep_class c39b6e86b5e485e0 javax_swing_Timer__24Waker

// header file dependencies
// @dep_header java_lang_Thread

#include "java/lang/Thread.h"

#ifndef _JC_javax_swing_Timer__24Waker_H_
#define _JC_javax_swing_Timer__24Waker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_Timer$object;
struct _jc_javax_swing_Timer__241$object;

// Typedefs
typedef struct _jc_javax_swing_Timer__24Waker$sub_refs	_jc_javax_swing_Timer__24Waker$sub_refs;
typedef struct _jc_javax_swing_Timer__24Waker$sub_nonrefs	_jc_javax_swing_Timer__24Waker$sub_nonrefs;
typedef struct _jc_javax_swing_Timer__24Waker$refs	_jc_javax_swing_Timer__24Waker$refs;
typedef struct _jc_javax_swing_Timer__24Waker$nonrefs	_jc_javax_swing_Timer__24Waker$nonrefs;
typedef struct _jc_javax_swing_Timer__24Waker$object	_jc_javax_swing_Timer__24Waker$object;

typedef const struct _jc_javax_swing_Timer__24Waker$vmethods	_jc_javax_swing_Timer__24Waker$vmethods;
typedef const struct _jc_javax_swing_Timer__24Waker$vtable	_jc_javax_swing_Timer__24Waker$vtable;
typedef const struct _jc_javax_swing_Timer__24Waker$vtype	_jc_javax_swing_Timer__24Waker$vtype;

// Constructors
extern void _jc_javax_swing_Timer__24Waker$method$_init$89ba0a27c03d729e(_jc_env *, struct _jc_javax_swing_Timer__24Waker$object *, struct _jc_javax_swing_Timer$object *);
extern void _jc_javax_swing_Timer__24Waker$method$_init$e5645f6d07888112(_jc_env *, struct _jc_javax_swing_Timer__24Waker$object *, struct _jc_javax_swing_Timer$object *, struct _jc_javax_swing_Timer__241$object *);

// Virtual methods
extern void _jc_javax_swing_Timer__24Waker$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_javax_swing_Timer__24Waker$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_Timer__24Waker$method_info$run$8b940e4957c86ebf;

// Virtual methods structure
struct _jc_javax_swing_Timer__24Waker$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_javax_swing_Timer__24Waker$object *);
};

// Vtable
struct _jc_javax_swing_Timer__24Waker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Thread$vmethods	java_lang_Thread;
	_jc_javax_swing_Timer__24Waker$vmethods	javax_swing_Timer__24Waker;
};

// Vtype
struct _jc_javax_swing_Timer__24Waker$vtype {
	_jc_type			type;
	_jc_javax_swing_Timer__24Waker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_Timer__24Waker$sub_refs {
	struct _jc_javax_swing_Timer$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_Timer__24Waker$refs {
    _jc_javax_swing_Timer__24Waker$sub_refs	javax_swing_Timer__24Waker;
    _jc_java_lang_Thread$sub_refs	java_lang_Thread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_Timer__24Waker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_Timer__24Waker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Thread$sub_nonrefs	java_lang_Thread;
    _jc_javax_swing_Timer__24Waker$sub_nonrefs	javax_swing_Timer__24Waker;
};

// Object instance structure
struct _jc_javax_swing_Timer__24Waker$object {
	_jc_javax_swing_Timer__24Waker$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_Timer__24Waker$vtype	*vtype;
	_jc_javax_swing_Timer__24Waker$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_Timer__24Waker$vtype _jc_javax_swing_Timer__24Waker$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_Timer__24Waker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_Timer__24Waker$class_object;

#endif	/* _JC_javax_swing_Timer__24Waker_H_ */

==> jc-1.4.6.tar.gz: javax/swing/Timer__24Waker.h <==
// class javax.swing.Timer$Waker

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7e33d4feabbc3f15 java_lang_Thread
// @dep_class 2d7def0e302c8da4 javax_swing_Timer__24Waker

// header file dependencies
// @dep_header java_lang_Thread

#include "java/lang/Thread.h"

#ifndef _JC_javax_swing_Timer__24Waker_H_
#define _JC_javax_swing_Timer__24Waker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_Timer$object;
struct _jc_javax_swing_Timer__241$object;

// Typedefs
typedef struct _jc_javax_swing_Timer__24Waker$sub_refs	_jc_javax_swing_Timer__24Waker$sub_refs;
typedef struct _jc_javax_swing_Timer__24Waker$sub_nonrefs	_jc_javax_swing_Timer__24Waker$sub_nonrefs;
typedef struct _jc_javax_swing_Timer__24Waker$refs	_jc_javax_swing_Timer__24Waker$refs;
typedef struct _jc_javax_swing_Timer__24Waker$nonrefs	_jc_javax_swing_Timer__24Waker$nonrefs;
typedef struct _jc_javax_swing_Timer__24Waker$object	_jc_javax_swing_Timer__24Waker$object;

typedef const struct _jc_javax_swing_Timer__24Waker$vmethods	_jc_javax_swing_Timer__24Waker$vmethods;
typedef const struct _jc_javax_swing_Timer__24Waker$vtable	_jc_javax_swing_Timer__24Waker$vtable;
typedef const struct _jc_javax_swing_Timer__24Waker$vtype	_jc_javax_swing_Timer__24Waker$vtype;

// Constructors
extern void _jc_javax_swing_Timer__24Waker$method$_init$89ba0a27c03d729e(_jc_env *, struct _jc_javax_swing_Timer__24Waker$object *, struct _jc_javax_swing_Timer$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_Timer__24Waker$method$_init$e5645f6d07888112(_jc_env *, struct _jc_javax_swing_Timer__24Waker$object *, struct _jc_javax_swing_Timer$object *, struct _jc_javax_swing_Timer__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_Timer__24Waker$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_javax_swing_Timer__24Waker$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_Timer__24Waker$method_info$run$8b940e4957c86ebf;

// Virtual methods structure
struct _jc_javax_swing_Timer__24Waker$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_javax_swing_Timer__24Waker$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_Timer__24Waker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Thread$vmethods	java_lang_Thread;
	_jc_javax_swing_Timer__24Waker$vmethods	javax_swing_Timer__24Waker;
};

// Vtype
struct _jc_javax_swing_Timer__24Waker$vtype {
	_jc_type			type;
	_jc_javax_swing_Timer__24Waker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_Timer__24Waker$sub_refs {
	struct _jc_javax_swing_Timer$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_Timer__24Waker$refs {
    _jc_javax_swing_Timer__24Waker$sub_refs	javax_swing_Timer__24Waker;
    _jc_java_lang_Thread$sub_refs	java_lang_Thread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_Timer__24Waker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_Timer__24Waker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Thread$sub_nonrefs	java_lang_Thread;
    _jc_javax_swing_Timer__24Waker$sub_nonrefs	javax_swing_Timer__24Waker;
};

// Object instance structure
struct _jc_javax_swing_Timer__24Waker$object {
	_jc_javax_swing_Timer__24Waker$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_Timer__24Waker$vtype	*vtype;
	_jc_javax_swing_Timer__24Waker$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_Timer__24Waker$vtype _jc_javax_swing_Timer__24Waker$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_Timer__24Waker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_Timer__24Waker$class_object;

#endif	/* _JC_javax_swing_Timer__24Waker_H_ */
